==> deepin-deb-installer_5.8.1.orig.tar.gz: deepin-deb-installer-5.8.1/assets/deepin-deb-installer/package-installer/zh_HK/package-installer.md <==
# 軟件包安裝器|deepin-deb-installer|

## 概述

軟件包安裝器是一款deb包管理工具，方便用戶安裝應用商店以外的其他應用。界面簡單易用，支持批量安裝、版本訊息識別和依賴自動補全等功能，以幫助您快速的實現安裝操作。

   ![0|run](fig/run.png)

## 操作介紹

### 打開方式

您可以使用以下方法打開軟件包安裝器：

- 雙擊deb包，軟件包安裝器會自動啟動並準備安裝該軟件包。
- 直接將deb包拖拽到圖標上打開應用。

### 安裝

軟件包安裝器可以安裝單個應用，也可以批量安裝多個應用。

#### 單個安裝

1.  在軟件包安裝器界面，您可以：
   - 單擊 **選擇文件** ，選擇需要安裝的軟件包，單擊 **打開**。
   - 直接將軟件包拖拽到應用界面。
2.  單擊 **安裝**。
3.  如果彈出授權窗口，請輸入密碼授權。
4.  安裝過程中可以單擊 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展開或收起安裝進程訊息。
5.  安裝成功之後，單擊 **完成** 退出，或者單擊 **返回** 繼續安裝其他應用。

   ![0|success](fig/single.png)

#### 多個安裝

軟件包安裝器可以通過拖拽和選擇文件的方式一次性批量添加多個軟件包，安裝步驟請參考 [單個安裝](#單個安裝)，多個安裝時請注意以下要點：

- 批量安裝同樣也可以查看安裝進程。
- 批量安裝時按鈕只顯示 **安裝** 按鈕。本地已安裝其他版本的軟件包執行安裝操作，本地已安裝相同版本的軟件包執行重新安裝操作。
- 批量安裝列表內，選擇一個安裝包，單擊鼠標右鍵選擇 **刪除** 可將安裝包從安裝列表移除。


   ![0|mult](fig/multi.png)

#### 無法安裝

軟件包安裝器可以自動識別無法安裝的包，有效規避安裝後無法使用的問題。

請留意界面提示並確定，常見的原因有：

- 軟件包架構不匹配。

   ![0|cant](fig/cant1.png)

- 依賴關係不滿足。

   ![0|cant](fig/cant2.png)

- 安裝包無數字簽名。

   請根據對話框提示，在 **控制中心 > 常規** 中開啟開發者模式後，再進行安裝。
   
   ![0|cant](fig/cant3.png)
   
- 安裝包沒有有效的數字簽名。

   ![0|cant](fig/cant4.png)

### 卸載

當安裝包已存在相同或其他版本時，可以使用軟件包安裝器執行卸載操作。

1.  在軟件包安裝器界面，您可以：
   - 單擊 **選擇文件** ，選擇需要安裝的軟件包，單擊 **打開**。
   - 直接將軟件包拖拽到應用界面。
2. 單擊 **卸載**。
3. 請注意界面上的卸載提示，單擊 **確定卸載**。如果彈出授權窗口，請輸入密碼授權。
4. 卸載過程中可以單擊 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展開或收起卸載進程訊息。
5. 卸載成功後單擊 **完成**。

   ![0|uninstall](fig/uninstall.png)

> ![attention](../common/attention.svg)注意：卸載某些應用可能會對系統或其他軟件產生影響，請謹慎操作。

> ![notes](../common/notes.svg)說明：若檢測到已安裝的軟件版本較新時，則顯示 **安裝舊版本** 按鈕，您可退回到舊版本；若檢測到已安裝的軟件版本較舊時，則顯示 **更新** 按鈕，您可更新版本。

## 主菜單

在主菜單中，您可以切換窗口主題、查看幫助手冊，了解軟件包安裝器的更多訊息。

### 主題

窗口主題包含淺色主題、深色主題和系統主題。

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **主題**，選擇一個主題顏色。

### 幫助

查看幫助手冊，進一步了解和使用軟件包安裝器。

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **幫助**。
3. 查看軟件包安裝器的幫助手冊。


### 關於

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **關於**。
3. 查看軟件包安裝器的版本和介紹。


### 退出

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **退出**。

==> deepin-deb-installer_6.5.5.orig.tar.gz: deepin-deb-installer-6.5.5/assets/deepin-deb-installer/package-installer/zh_HK/package-installer.md <==
# 軟件包安裝器|deepin-deb-installer|

## 概述

軟件包安裝器是一款deb包管理工具，界面簡單易用，支持批量安裝、版本訊息識別和依賴包自動補全等功能，以幫助您快速的實現安裝操作。

![0|run](fig/run.png)

## 操作介紹

### 打開方式

您可以使用以下方法打開軟件包安裝器：

- 雙擊deb包，軟件包安裝器會自動啟動並準備安裝該軟件包。
- 直接將deb包拖拽到圖標上打開應用。

### 安裝

軟件包安裝器可以安裝單個應用，也可以批量安裝多個應用。

#### 單個安裝

1.  在軟件包安裝器界面，您可以：
   - 單擊 **選擇文件** ，選擇需要安裝的軟件包，單擊 **打開**。
   - 直接將軟件包拖拽到應用界面。
2.  單擊 **安裝**，彈出授權窗口，請輸入密碼授權。
3.  安裝過程中可以單擊 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展開或收起安裝進程訊息。
4.  安裝成功之後，單擊 **完成** 退出，或者單擊 **返回** 繼續安裝其他應用。

![0|success](fig/single.png)

> ![notes](../common/notes.svg) 說明：當檢測到已安裝的軟件版本高於或低於待安裝的版本時，界面會顯示 **安裝舊版本** 或 **更新** 按鈕，您可以根據需要退回到舊版本或更新到新版本。


#### 多個安裝

軟件包安裝器可以通過拖拽和選擇文件的方式一次性批量添加多個軟件包，安裝步驟請參考 [單個安裝](#單個安裝)，多個安裝時請注意以下要點：

- 批量安裝同樣也可以查看安裝進程。
- 批量安裝時按鈕只顯示 **安裝** 按鈕。本地已安裝其他版本的軟件包執行安裝操作，本地已安裝相同版本的軟件包執行重新安裝操作。
- 批量安裝列表內，選擇一個安裝包，單擊鼠標右鍵選擇 **刪除** 可將安裝包從安裝列表移除。

![0|mult](fig/multi.png)


#### 無法安裝

軟件包安裝器可以自動識別無法安裝的包，有效規避安裝後無法使用的問題。

常見的原因有：

- 軟件包架構不匹配。

![0|cant](fig/cant1.png)

- 依賴關係不滿足。

![0|cant](fig/cant2.png)


### 卸載

當安裝包已存在相同或其他版本時，可以使用軟件包安裝器執行卸載操作。

1.  在軟件包安裝器界面，您可以：
   - 單擊 **選擇文件** ，選擇需要安裝的軟件包，單擊 **打開**。
   - 直接將軟件包拖拽到應用界面。
2. 單擊 **卸載**。
3. 請注意界面上的卸載提示，單擊 **確定卸載**，彈出授權窗口，請輸入密碼授權。
4. 卸載過程中可以單擊 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展開或收起卸載進程訊息。
5. 卸載成功後單擊 **完成**。

![0|uninstall](fig/uninstall.png)

> ![attention](../common/attention.svg) 注意：卸載某些應用可能會對系統或其他軟件產生影響，請謹慎操作。


## 主菜單

在主菜單中，您可以切換窗口主題、查看幫助手冊，了解軟件包安裝器的更多訊息。

### 主題

窗口主題包含淺色主題、深色主題和系統主題。

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **主題**，選擇一個主題顏色。

### 幫助

查看幫助手冊，進一步了解和使用軟件包安裝器。

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **幫助**。
3. 查看軟件包安裝器的幫助手冊。


### 關於

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **關於**。
3. 查看軟件包安裝器的版本和介紹。


### 退出

1. 在軟件包安裝器界面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 選擇 **退出**。
